﻿using System;
using System.Threading.Tasks;
using System.Collections.Generic;
using Android.App;
using Android.Widget;
using Android.Provider;
using Android.Content;
using Android.Media;
using Android.Views;

namespace VJGameForms.Droid
{
	public class BaseRenderer
	{
		Random _rnd = new Random();
		Task _timer;
		const int StartTimeSpan = 1000;
		int _time = StartTimeSpan;
		DateTime _date;
		double _elapsed = StartTimeSpan;
		List<Android.Net.Uri> _uriList = new List<Android.Net.Uri>();
		ImageView _imageView;
		int _preIndex = 0;
		MediaPlayer[] _sound = new MediaPlayer[2];

		public BaseRenderer(Activity activity,View view)
		{
			SDCard(activity);
			SetImageView(view);
			InitSound(activity);
			RepeatSound(activity);
		}

		void SDCard(Activity activity)
		{
			var cursor = activity.ContentResolver.Query(
			MediaStore.Images.Media.ExternalContentUri, null, null, null, null);
			cursor.MoveToFirst();
			int fieldIndex;
			long id;
			do
			{
				fieldIndex = cursor.GetColumnIndex(MediaStore.Images.Media.InterfaceConsts.Id);
				id = cursor.GetLong(fieldIndex);
				var bmpUri = ContentUris.WithAppendedId(
					MediaStore.Images.Media.ExternalContentUri, id);
				_uriList.Add(bmpUri);
			} while (cursor.MoveToNext());
		}

		void SetImageView(View view)
		{
			_imageView = view.FindViewById<ImageView>(Resource.Id.imageView);
			_imageView.SetImageURI(_uriList[_preIndex]);
			_imageView.Click += PlaySound;
		}

		void InitSound(Activity activity)
		{
			_sound[0] = MediaPlayer.Create(activity, Resource.Raw.VJ0);
			_sound[1] = MediaPlayer.Create(activity, Resource.Raw.VJ1);
		}

		void RepeatSound(Activity activity)
		{
			_timer = new Task(async () =>
			{
				while (true)
				{
					if (_timer == null) return;
					activity.RunOnUiThread(() =>
					{
						int index = _rnd.Next(_uriList.Count);
						while (index == _preIndex)
						{
							index = _rnd.Next(_uriList.Count);
						}
						_imageView.SetImageURI(_uriList[index]);
						_preIndex = index;
						if (_time <= 500)
						{
							_timer.Dispose();
							_timer = null;
							App.Current.MainPage = new GameClearPage();
							return;
						}
					});
					_date = DateTime.Now;
					_sound[0].Start();
					if (_time <= 500)
					{
					}
					else if (_elapsed < (double)_time)
					{
						_time -= (int)(StartTimeSpan * 0.02);
					}
					else
					{
						_time = StartTimeSpan;
					}
					_elapsed = StartTimeSpan;
					await Task.Delay(_time);
				}
			});
			_timer.Start();
		}

		public void PlaySound(object sender, EventArgs e)
		{
			_sound[1].Start();
			if (_elapsed >= StartTimeSpan)
			{
				_elapsed = _date.Subtract(DateTime.Now).TotalMilliseconds * -1;
			}
			else
			{
				_elapsed = StartTimeSpan;
			}
		}
	}
}
