﻿using VJGameForms;
using VJGameForms.iOS;
using System;
using Xamarin.Forms;
using Xamarin.Forms.Platform.iOS;
using UIKit;
using Photos;
using Foundation;
using CoreGraphics;

[assembly: ExportRenderer(typeof(VJGamePage), typeof(VJGameRenderer))]

namespace VJGameForms.iOS
{
	public class VJGameRenderer : PageRenderer
	{
		MyImageView _imageView;
		MySound _sound = new MySound();
		const long StartTimeSpan = 10000000;
		long _time = StartTimeSpan;
		DateTime _date;
		double _elapsed = StartTimeSpan;

		protected override void OnElementChanged(VisualElementChangedEventArgs e)
		{
			base.OnElementChanged(e);

			if (e.OldElement != null || Element == null)
			{
				return;
			}

			try
			{
				_imageView = new MyImageView(this);
				Authorization();
			}
			catch (Exception ex)
			{
				System.Diagnostics.Debug.WriteLine(@"	ERROR: ", ex.Message);
			}
		}

		private async void Authorization()
		{
			var status = PHPhotoLibrary.AuthorizationStatus;
			if (status != PHAuthorizationStatus.Authorized)
			{
				await PHPhotoLibrary.RequestAuthorizationAsync();
			}
			_imageView.ReadImage(View.Bounds);
			RepeatSound();
			Add(_imageView);
		}

		void RepeatSound()
		{
			_date = DateTime.Now;
			_imageView.RandomImage();
			NSTimer.CreateScheduledTimer(new TimeSpan(_time), (obj) =>
			{
				_sound.PlaySound(0);
				if (_time <= 3000000)
				{
					App.Current.MainPage = new GameClearPage();
					return;
				}
				else if (_elapsed < (double)_time * 0.0003)
				{
					_time -= (long)(StartTimeSpan * 0.025);
				}
				else
				{
					_time = StartTimeSpan;
				}
				_elapsed = StartTimeSpan;
				RepeatSound();
			});
		}

		public void PlaySound()
		{
			_sound.PlaySound(1);
			if (_elapsed >= StartTimeSpan)
			{
				_elapsed = _date.Subtract(DateTime.Now).TotalMilliseconds * -1;
			}
			else
			{
				_elapsed = StartTimeSpan;
			}
		}
	}
}
